Documentation
¶
Index ¶
- func Joiner(channels ...<-chan fmt.Stringer) <-chan fmt.Stringer
- func LetterCounter(sentences <-chan string) <-chan fmt.Stringer
- func Printer(values <-chan fmt.Stringer) <-chan struct{}
- func Spliter(sentences <-chan string) (<-chan string, <-chan string)
- func WordCounter(sentences <-chan string) <-chan fmt.Stringer
- type Letters
- type Words
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LetterCounter ¶
LetterCounter is a process that counts letters in a string
func WordCounter ¶
WordCounter is a step that counts the words in a string
Types ¶
Click to show internal directories.
Click to hide internal directories.